import click
from new_project import about
from new_project.cli import CustomGroup
from new_project.settings import Settings


APPNAME = about.appname
VERSION = about.version

# The `click` custom context settings
CONTEXT_SETTINGS = dict(
    auto_envvar_prefix=APPNAME.upper().replace('-', '_'),
)


# Callback for py.test self-test option '--test'
def self_test(ctx, param, value):
    if not value or ctx.resilient_parsing:
        return
    import pytest
    pytest.main('')
    ctx.exit()


###
# Main CLI
###
@click.command(
    cls=CustomGroup,
    context_settings=CONTEXT_SETTINGS
)
@click.version_option(version=VERSION)
@click.option(
    '--log', 'log_level',
    type=click.Choice(['debug', 'info', 'warn', 'error']),
    default='error',
    help='Logging level [default: error]).'
)
@click.option(
    '--config', 'config_file',
    type=click.Path(exists=True, readable=True, resolve_path=True),
    help='Load given configuration file.'
)
@click.option(
    '--test',
    is_flag=True,
    callback=self_test, is_eager=True, expose_value=False,
    help='Run self test.'
)
@click.pass_context
def main(ctx, log_level, config_file):
    """'vault-init' Vault initialization and unseal automation."""
    ctx.obj = Settings(config_file)
    ctx.obj.log_level = log_level
