from invoke import task
from tasks import utils


@task
def init(ctx):
    """Initialize new git repo"""
    msg = 'git - Initialize git repository'
    cmd = 'git init'
    utils.run_with_feedback(ctx, cmd, msg)


def stage(ctx):
    """git - Stage all"""
    msg = 'git - Stage project'
    cmd = 'git add .'
    utils.run_with_feedback(ctx, cmd, msg)


def commit(ctx, message='Initial commit'):
    """git - commit"""
    msg = 'git - Initial commit'
    cmd = 'git commit -m "{0}"'.format(message)
    utils.run_with_feedback(ctx, cmd, msg)


def tag(ctx, tagname, message):
    """Tag the current working directory state"""
    msg = 'git - tag: "{0}"'.format(tagname)
    cmd = 'git tag -a -m "{0}" "{1}"'.format(message, tagname)
    utils.run_with_feedback(ctx, cmd, msg)


@task
def flow_init(ctx):
    msg = 'Initialize git-flow'
    responses = {
        r'Branch name for production releases'       : 'master\n',
        r'Branch name for "next release" development': 'develop\n',
        r'Feature branches?'                         : 'feature/\n',
        r'Release branches?'                         : 'release/\n',
        r'Hotfix branches?'                          : 'hotfix/\n',
        r'Support branches?'                         : 'support/\n',
        r'Version tag prefix?'                       : 'v\n'
    }
    cmd = 'git flow init'
    utils.run_with_feedback(ctx, cmd, msg, responses=responses)
