import setuptools_scm
from invoke import task
from new_project import about
from new_project import PKG_ROOT


@task(help={
    'type': 'See Docstring:',
    'supress': 'Supress output, used when calling programmatically'
})
def version(ctx, type, supress=False):
    """Extracts version info from various sources.

    -t, --type: The source for the version info which is one of
        'dev': The current development version constructed from git as
            reported by setuptools_scm.

        'about': The version attribute from the checked out 'about.py' file.

        'install': The version reported by the app itself when installed by
            'setup.py install'"""
    if type=='about':
        version = about.version
    elif type=='dev':
        version = setuptools_scm.get_version()
    elif type=='install':
        cmd = '{0} --version'.format(about.appname)
        results = ctx.run(cmd, hide=True)
        version = results.stdout

    if supress:
        return version
    else:
        print(version)


@task
def bump(ctx, v=None):
    if v is not None:
        new_version = v
    else:
        new_version = version(ctx, type='dev', supress=True)
    current_version = version(ctx, type='about', supress=True)

    about_file = PKG_ROOT / 'about.py'

    orig_about = about_file.read_text()
    new_about = orig_about.replace(current_version, new_version)

    about_file.write_text(new_about)




