import venv
from pathlib import Path
from tasks import utils


def pip_install(ctx, venv_prefix, pkg=None, file=None):
    """Installs either a package or a requirements like file, but not
    both, into the given venv"""
    if bool(pkg) == bool(file):
        raise RuntimeError

    cmd = ''
    msg = ''
    if pkg:
        cmd = '{0}/bin/pip install -U {1}'.format(venv_prefix, pkg)
        msg = 'Install package "{0}"'.format(pkg)
    elif file:
        cmd = '{0}/bin/pip install -U -r {1}'.format(venv_prefix, file)
        msg = 'Install "{0}"'.format(file)

    utils.run_with_feedback(ctx, cmd, msg)


def run_venv_py(ctx, venv_prefix, script, *args):
    """Runs a python script in the context of a virtual environment.

    Args:
        venv_prefix (PosixPath|str): Path to venv root.
        script (str): Python script to run.
        *args: Python script argument list.

    Returns:
        Invoke run result

    """
    params = ' '.join(args)

    cmd = '{0}/bin/python {1} {2}'.format(venv_prefix, script, params)
    msg = 'Run "{0} {1}"'.format(script, params)
    utils.run_with_feedback(ctx, cmd, msg)


def venv_py(venv_prefix):
    return Path('{0}/bin/python'.format(venv_prefix))


def create_venv():
    """Creates a virtual environment in the current working dir.

    Returns:
        PosixPath:

        Returns an absolute path object to the new venv. This is the path that
        would normally be set to sys.prefix.

    """
    msg = 'Create Virtual Environment'
    print(msg, end='', flush=True)

    env = venv.EnvBuilder(with_pip=True)
    env_dir = '.venv'
    env.create(env_dir)

    print(' ==> OK')

    return Path(env_dir).resolve()
